@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2015 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 # 
 # PyHoca is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -243,8 +243,14 @@ FunctionEnd
 ;--------------------------------
 
 ;--------------------------------
+;Installer Sections
 
-; The stuff to install
+;"Recommended" is the default because it is specified 1st.
+InstType "Recommended"
+InstType "Full"
+InstType "Minimal"
+
+; The application and all its required dependencies
 Section "{program_name} ($REQUIRED)"
 
   SectionIn RO
@@ -253,7 +259,10 @@ Section "{program_name} ($REQUIRED)"
   ; Empty $INSTDIR before writing new files to it.
   RmDir /r "$INSTDIR\\*.*"
   ; Install new files...
-  File /r /x .svn /x .git "${{distOutputDirectory}}\\*.*"
+  ; Due to a limitation of nsis, we cannot tell it to exclude vcxsrv\\fonts
+  ; specifically. Instead, we must tell it to match every folder named
+  ; "fonts" (of which there is only one.)
+  File /r /x .svn /x .git /x fonts "${{distOutputDirectory}}\\*.*"
 
   ; Write the installation path into the registry
   WriteRegStr HKLM SOFTWARE\\{program_name} "Install_Dir" "$INSTDIR"
@@ -275,9 +284,66 @@ Section "{program_name} ($REQUIRED)"
 
 SectionEnd
 
+SectionGroup "Fonts"
+
+  ;Empirical testing shows that "misc" fixes compatibility for the majority
+  ;of applications with font compatibility programs.
+  ;So lets make "misc" be part of "recommended", and therefore the default.
+  ;
+  ;As of VcXsrv-xp 1.14.3.2
+  ;misc is 412 files at 6.80 MB (7.94 MB on disk)
+  Section "misc" fonts-misc
+    ; SectionIn Recommended & Full
+    SectionIn 1 2
+    SetOutPath "$INSTDIR\\vcxsrv\\fonts\\"
+    File "${{distOutputDirectory}}\\vcxsrv\\fonts\\fonts.conf"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\misc"
+  SectionEnd
+
+  ;As of VcXsrv-xp 1.14.3.2
+  ;75dpi is 1,897 files at 10.7 MB (15.6 MB on disk)
+  Section "75dpi" fonts-75dpi
+    ; SectionIn Full
+    SectionIn 2
+    SetOutPath "$INSTDIR\\vcxsrv\\fonts\\"
+    File "${{distOutputDirectory}}\\vcxsrv\\fonts\\fonts.conf"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\75dpi"
+  SectionEnd
+
+  ;As of VcXsrv-xp 1.14.3.2
+  ;100dpi is 1,897 files at 12.3 MB (16.8 MB on disk)
+  Section "100dpi" fonts-100dpi
+    ; SectionIn Full
+    SectionIn 2
+    SetOutPath "$INSTDIR\\vcxsrv\\fonts\\"
+    File "${{distOutputDirectory}}\\vcxsrv\\fonts\\fonts.conf"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\100dpi"
+  SectionEnd
+
+  ;As of VcXsrv-xp 1.14.3.2
+  ;everything else is 466 files at 12.8MB (13.8 MB on disk)
+  Section "others" fonts-others
+    ; SectionIn Full
+    SectionIn 2
+    SetOutPath "$INSTDIR\\vcxsrv\\fonts\\"
+    File "${{distOutputDirectory}}\\vcxsrv\\fonts\\fonts.conf"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\cyrillic"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\encodings"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\OTF"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\Speedo"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\terminus-font"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\TTF"
+    File /r "${{distOutputDirectory}}\\vcxsrv\\fonts\\Type1"
+  SectionEnd
+
+SectionGroupEnd
+
 ; Optional section (can be disabled by the user)
 Section "$STARTMENU_LINKS"
 
+  ; SectionIn Recommended & Full
+  SectionIn 1 2
+
   SetOutPath "$INSTDIR"
   CreateDirectory "$SMPROGRAMS\\{program_name}"
   CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
@@ -292,6 +358,9 @@ SectionEnd
 ; Optional section (can be disabled by the user)
 Section "$DESKTOP_LINKS"
 
+  ; SectionIn Recommended & Full
+  SectionIn 1 2
+
   SetOutPath "$INSTDIR"
   CreateShortCut "$DESKTOP\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
 
