@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2014 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
-# Copyright (C) 2010-2014 by Dick Kniep <dick.kniep@lindix.nl>
+# Copyright (C) 2010-2015 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2015 by Dick Kniep <dick.kniep@lindix.nl>
 #
 # PyHoca GUI is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -26,6 +26,13 @@ import x2go
 import wx
 import os
 
+# Warning: If pyflakes says you should delete these 2 lines,
+# then pyflakes is wrong. Deleting these 2 lines will break
+# the Windows build by preventing win32gui.pyd from being
+# copied over.
+if x2go.X2GOCLIENT_OS == 'Windows':
+    import win32gui
+
 # PyHoca-GUI modules
 import menus_taskbar
 import basepath
